import { select } from 'd3';

const svg = select('#Plot1').append("svg");

const margin = {top: 20, right: 20, bottom: 90, left: 50};
const width = +window.innerWidth - margin.left - margin.right;
const height = 400 - margin.top - margin.bottom;

svg.attr('width', width + margin.left + margin.right);
svg.attr("height", height + margin.top + margin.bottom);

const group = svg.append("g")
									.attr("transform", "translate(" + margin.left + "," + margin.top + ")");

function drawPlot1(data) {
  var groupedData = d3.group(data, d => d["Category"]);
  console.log(groupedData);
  var groupedSubGroup = new Map();
  var domain = [];
  groupedData.forEach((d, i) => {
    // console.log(d)
    domain.push(i);
  	groupedSubGroup.set(i, d3.stack().keys(["Customer Name", "Sales"])(d))
  })
  //console.log(groupedSubGroup)
  
  //throw Error();
  
  var yScale = d3.scaleLinear()
                .domain([0, d3.max(groupedData, d => {
                	return d3.sum(d[1], _d => _d.Sales);
                })])
                .range([height, 0])
  
  var xScale = d3.scaleBand()
    .range([0, width])
  	//.domain(data.map(function(d) { return d["Sub-Category"]; }))
  	.domain(domain)
  	.padding(0.2)
  
  var xAxis = d3.axisBottom(xScale);
  var yAxis = d3.axisLeft(yScale);
  
  group.append("g")
      .attr('transform', "translate(0, 0)")
      .classed('y-axis', true)
      .call(yAxis);
  
  group.append("g")
      .attr('transform', "translate(0," + height + ")")
      .classed('x-axis', true)
      .call(xAxis)
      .selectAll("text")
      .attr("transform", "translate(-10,0)rotate(-60)")
      .style("text-anchor", "end");
  
  	console.log(groupedData)

  
  	/*group.selectAll("g")
  				.data(data)
  				.enter()
  				.append("g")
  				// .attr("fill", function(d) { return color(d.key); })
  				.selectAll("rect")
  				.data(function(d) { return groupedData.get(d["Sub-Category"]);})
  				.enter()
  				.append("rect")
  
  	throw Error()*/
  
  	group.selectAll('rect')
        //.data(data)
  			.data(domain)
        .enter()
        .append('rect')
        .attr('width', xScale.bandwidth())
        .attr('height', function(indexName) { return height - yScale(d3.sum(
                                                                      groupedData.get(indexName),
                                                                      _d => _d.Sales
                                                                    )
                                                            ); })
  			.attr('x', indexName => xScale(indexName))
  			.attr('y', indexName => {
      			return yScale(
              				d3.sum(
                        groupedData.get(indexName),
                        _d => _d.Sales
                      )
            )} )
  			//.attr("Sales", indexName => d["Sales"])
  			.style("opacity", .8)
  			.on("mouseover", d => {
      		d3.select(this)
            .style("fill", "red")
      			.style("stroke", "green")
      			.style("fill", "blue")
    		})
  			.on("click", indexName => {
          document.dispatchEvent(new CustomEvent("categoryClicked", {detail: {selectedCategory: indexName}}));
    		})
  			.append('title').text(indexName => {return indexName +": "+ d3.sum(
                                                                            groupedData.get(indexName),
                                                                            _d => _d.Sales
                                                                          )
                                   });
  			/*.on("mouseover", d => {
      			tooltip.transition()		
                .duration(200)		
                .style("opacity", .9);		
            tooltip.html(d.Country + "<br/>"  + d["2022 Population"])	
                .style("display", "block")
              	.style("position", "absolute")
              	.style("left", (d3.event.pageX) + "px")		
                .style("top", (d3.event.pageY - 28) + "px");	
    		})
  			.on("mouseleave", d => {
      		tooltip.style("display", "none")
    		})*/
}

var data = [];
d3.csv("data.csv")
  .then(loadedData => {
  console.log(loadedData)
  
  		data = loadedData;
          
			drawPlot1(data)
  	
	})