import { select } from 'd3';

const svg = select('#Plot3').append("svg");

const margin = {top: 20, right: 20, bottom: 90, left: 50};
const width = +window.innerWidth - margin.left - margin.right;
const height = 400 - margin.top - margin.bottom;

// The radius of the pieplot is half the width or half the height (smallest one). I subtract a bit of margin.
var radius = Math.min(width, height) / 2 + margin.left;
console.log("radius", radius)
svg.attr('width', width + margin.left + margin.right);
svg.attr("height", height + margin.top + margin.bottom);

const group = svg.append("g")
									.attr("transform", "translate(" + radius + "," + radius + ")");

var selected_category = "";

function drawPlot3(data) {
  var groupedData = d3.group(data, d => d["Category"]);
  
  var selectedGroup_data = groupedData.get(selected_category);
  
  var subGroupedData = d3.group(data, d => d["Sub-Category"]);
  
  var subCategory_sales = new Map();
  subGroupedData.forEach((d, i) => {
   	 subCategory_sales.set(
       	i,
     		d3.sum(d, _d => +_d.Sales)
     )
  })
  console.log("subCategory_sales", subCategory_sales)
    
  /*var colorScale = d3.scaleLinear()
  									.domain([0, d3.max(subCategory_sales, d => +d[1])])
          					.range(["#eff3ff", "#084594"])
  */ var colorScale = d3.scaleOrdinal()
                      .domain([0, subCategory_sales.size])
                      .range(d3.schemeSet3);
    
  // Compute the position of each group on the pie:
var pie = d3.pie()
  				.value(function(d) {return d.value; })
var data_ready = pie(d3.entries(Object.fromEntries(subCategory_sales)))

console.log(subCategory_sales)
console.log(data_ready)

// Build the pie chart: Basically, each part of the pie is a path that we build using the arc function.
group
  .selectAll('path')
  .data(data_ready)
  .enter()
  .append('path')
  .attr('d', d3.arc()
    .innerRadius(100)         // This is the size of the donut hole
    .outerRadius(radius)
  )
  .attr('fill', function(d){ return(colorScale(d.data.key)) })
  .attr("stroke", "black")
  .style("stroke-width", "2px")
  .style("opacity", 0.7)
  .append("title").text(d => d.data.key)
}

var data = [];
d3.csv("data.csv")
  .then(loadedData => {
  console.log(loadedData)
  
  		data = loadedData;
            	
	})

// Listen for the event.
document.addEventListener('categoryClicked', (e) => {
  // e.target matches elem
	group.selectAll("*").remove();
    
  selected_category = e.detail.selectedCategory;
  drawPlot3(data)
}, false);