import { select } from 'd3';

const svg = select('#Plot2').append("svg");

const margin = {top: 20, right: 20, bottom: 90, left: 50};
const width = +window.innerWidth - margin.left - margin.right;
const height = 400 - margin.top - margin.bottom;

svg.attr('width', width + margin.left + margin.right);
svg.attr("height", height + margin.top + margin.bottom);

const group = svg.append("g")
									.attr("transform", "translate(" + margin.left + "," + margin.top + ")");

var selected_category = "";

function drawPlot2(data) {
  var groupedData = d3.group(data, d => d["Category"]);
  
  var selectedGroup_data = groupedData.get(selected_category);
  
  var subGroupedData = d3.group(data, d => d["Sub-Category"]);
    
  // Add X axis
  var x = d3.scaleTime()
    .domain(d3.extent(selectedGroup_data, function(d) {
      
      //return d.map(_d => { return new Date(_d["Order Date"]);})
      return new Date(d["Order Date"]); 
    }))
    .range([ 0, width ]);
  group.append("g")
    .attr("transform", "translate(0," + height + ")")
    .call(d3.axisBottom(x));

  // Add Y axis
  var y = d3.scaleLinear()
    .domain([0, d3.max(selectedGroup_data, d => {
      						//return d.map(_d => {return _d.Sales;})
                	return d.Sales;
                })])
    .range([ height, 0]);
  group.append("g")
    .call(d3.axisLeft(y));
  
  // Add dots
  group.append('g')
    .selectAll("dot")
    .data(selectedGroup_data)
    .enter()
    .append("circle")
      .attr("cx", function (d) { return x(new Date(d["Order Date"])); } )
      .attr("cy", function (d) { return y(d.Sales); } )
      .attr("r", 1.5)
      .style("fill", "#69b3a2")
}

var data = [];
d3.csv("data.csv")
  .then(loadedData => {
  console.log(loadedData)
  
  		data = loadedData;
            	
	})

// Listen for the event.
document.addEventListener('categoryClicked', (e) => {
  // e.target matches elem
	group.selectAll("*").remove();
  
  selected_category = e.detail.selectedCategory;
  drawPlot2(data)
}, false);